@@ -15,9 +15,9 @@
 
 import json
 import re
-import six
 import time
 
+import six
 from six.moves.urllib import parse
 from tempest import config
 from tempest.lib.common.utils import data_utils
@@ -578,7 +578,7 @@ class SharesV2Client(shares_client.SharesClient):
             time.sleep(self.build_interval)
             body = self.get_snapshot(snapshot_id, version=version)
             snapshot_status = body['status']
-            if snapshot_status == status:
+            if snapshot_status in status:
                 return
             if 'error' in snapshot_status:
                 raise (share_exceptions.
@@ -1522,7 +1522,7 @@ class SharesV2Client(shares_client.SharesClient):
             time.sleep(self.build_interval)
             body = self.show_share_server(server_id)
             server_status = body[status_attr]
-            if server_status == status:
+            if server_status in status:
                 return
             elif constants.STATUS_ERROR in server_status.lower():
                 raise share_exceptions.ShareServerBuildErrorException(
@@ -1654,20 +1654,23 @@ class SharesV2Client(shares_client.SharesClient):
             'share_id': share_id,
             'availability_zone': availability_zone,
         }
-
+        headers, extra_headers = utils.get_extra_headers(
+            version, constants.SHARE_REPLICA_GRADUATION_VERSION)
         body = json.dumps({'share_replica': post_body})
         resp, body = self.post(uri, body,
-                               headers=EXPERIMENTAL,
-                               extra_headers=True,
+                               headers=headers,
+                               extra_headers=extra_headers,
                                version=version)
         self.expected_success(202, resp.status)
         return self._parse_resp(body)
 
     def get_share_replica(self, replica_id, version=LATEST_MICROVERSION):
         """Get the details of share_replica."""
+        headers, extra_headers = utils.get_extra_headers(
+            version, constants.SHARE_REPLICA_GRADUATION_VERSION)
         resp, body = self.get("share-replicas/%s" % replica_id,
-                              headers=EXPERIMENTAL,
-                              extra_headers=True,
+                              headers=headers,
+                              extra_headers=extra_headers,
                               version=version)
         self.expected_success(200, resp.status)
         return self._parse_resp(body)
@@ -1676,8 +1679,10 @@ class SharesV2Client(shares_client.SharesClient):
         """Get list of replicas."""
         uri = "share-replicas/detail"
         uri += ("?share_id=%s" % share_id) if share_id is not None else ''
-        resp, body = self.get(uri, headers=EXPERIMENTAL,
-                              extra_headers=True, version=version)
+        headers, extra_headers = utils.get_extra_headers(
+            version, constants.SHARE_REPLICA_GRADUATION_VERSION)
+        resp, body = self.get(uri, headers=headers,
+                              extra_headers=extra_headers, version=version)
         self.expected_success(200, resp.status)
         return self._parse_resp(body)
 
@@ -1686,17 +1691,21 @@ class SharesV2Client(shares_client.SharesClient):
         """Get summary list of replicas."""
         uri = "share-replicas"
         uri += ("?share_id=%s" % share_id) if share_id is not None else ''
-        resp, body = self.get(uri, headers=EXPERIMENTAL,
-                              extra_headers=True, version=version)
+        headers, extra_headers = utils.get_extra_headers(
+            version, constants.SHARE_REPLICA_GRADUATION_VERSION)
+        resp, body = self.get(uri, headers=headers,
+                              extra_headers=extra_headers, version=version)
         self.expected_success(200, resp.status)
         return self._parse_resp(body)
 
     def delete_share_replica(self, replica_id, version=LATEST_MICROVERSION):
         """Delete share_replica."""
         uri = "share-replicas/%s" % replica_id
+        headers, extra_headers = utils.get_extra_headers(
+            version, constants.SHARE_REPLICA_GRADUATION_VERSION)
         resp, body = self.delete(uri,
-                                 headers=EXPERIMENTAL,
-                                 extra_headers=True,
+                                 headers=headers,
+                                 extra_headers=extra_headers,
                                  version=version)
         self.expected_success(202, resp.status)
         return body
@@ -1709,9 +1718,11 @@ class SharesV2Client(shares_client.SharesClient):
             'promote': None,
         }
         body = json.dumps(post_body)
+        headers, extra_headers = utils.get_extra_headers(
+            version, constants.SHARE_REPLICA_GRADUATION_VERSION)
         resp, body = self.post(uri, body,
-                               headers=EXPERIMENTAL,
-                               extra_headers=True,
+                               headers=headers,
+                               extra_headers=extra_headers,
                                version=version)
         self.expected_success(expected_status, resp.status)
         return self._parse_resp(body)
@@ -1720,8 +1731,10 @@ class SharesV2Client(shares_client.SharesClient):
                                             expected_status=200,
                                             version=LATEST_MICROVERSION):
         uri = "share-replicas/%s/export-locations" % replica_id
-        resp, body = self.get(uri, headers=EXPERIMENTAL,
-                              extra_headers=True, version=version)
+        headers, extra_headers = utils.get_extra_headers(
+            version, constants.SHARE_REPLICA_GRADUATION_VERSION)
+        resp, body = self.get(uri, headers=headers,
+                              extra_headers=extra_headers, version=version)
         self.expected_success(expected_status, resp.status)
         return self._parse_resp(body)
 
@@ -1731,8 +1744,10 @@ class SharesV2Client(shares_client.SharesClient):
                                           version=LATEST_MICROVERSION):
         uri = "share-replicas/%s/export-locations/%s" % (replica_id,
                                                          export_location_id)
-        resp, body = self.get(uri, headers=EXPERIMENTAL,
-                              extra_headers=True, version=version)
+        headers, extra_headers = utils.get_extra_headers(
+            version, constants.SHARE_REPLICA_GRADUATION_VERSION)
+        resp, body = self.get(uri, headers=headers,
+                              extra_headers=extra_headers, version=version)
         self.expected_success(expected_status, resp.status)
         return self._parse_resp(body)
 
@@ -1779,9 +1794,11 @@ class SharesV2Client(shares_client.SharesClient):
             }
         }
         body = json.dumps(post_body)
+        headers, extra_headers = utils.get_extra_headers(
+            version, constants.SHARE_REPLICA_GRADUATION_VERSION)
         resp, body = self.post(uri, body,
-                               headers=EXPERIMENTAL,
-                               extra_headers=True,
+                               headers=headers,
+                               extra_headers=extra_headers,
                                version=version)
         self.expected_success(202, resp.status)
         return self._parse_resp(body)
@@ -1797,9 +1814,11 @@ class SharesV2Client(shares_client.SharesClient):
             }
         }
         body = json.dumps(post_body)
+        headers, extra_headers = utils.get_extra_headers(
+            version, constants.SHARE_REPLICA_GRADUATION_VERSION)
         resp, body = self.post(uri, body,
-                               headers=EXPERIMENTAL,
-                               extra_headers=True,
+                               headers=headers,
+                               extra_headers=extra_headers,
                                version=version)
         self.expected_success(202, resp.status)
         return self._parse_resp(body)
@@ -1812,9 +1831,11 @@ class SharesV2Client(shares_client.SharesClient):
             'resync': None
         }
         body = json.dumps(post_body)
+        headers, extra_headers = utils.get_extra_headers(
+            version, constants.SHARE_REPLICA_GRADUATION_VERSION)
         resp, body = self.post(uri, body,
-                               headers=EXPERIMENTAL,
-                               extra_headers=True,
+                               headers=headers,
+                               extra_headers=extra_headers,
                                version=version)
         self.expected_success(expected_result, resp.status)
         return self._parse_resp(body)
@@ -1827,9 +1848,11 @@ class SharesV2Client(shares_client.SharesClient):
             'force_delete': None
         }
         body = json.dumps(post_body)
+        headers, extra_headers = utils.get_extra_headers(
+            version, constants.SHARE_REPLICA_GRADUATION_VERSION)
         resp, body = self.post(uri, body,
-                               headers=EXPERIMENTAL,
-                               extra_headers=True,
+                               headers=headers,
+                               extra_headers=extra_headers,
                                version=version)
         self.expected_success(202, resp.status)
         return self._parse_resp(body)
@@ -2084,3 +2107,90 @@ class SharesV2Client(shares_client.SharesClient):
         return body
 
 ###############
+
+    def share_server_migration_check(
+        self, share_server_id, host, writable=False,
+        preserve_snapshots=False, nondisruptive=False,
+        new_share_network_id=None, version=LATEST_MICROVERSION):
+        body = {
+            'migration_check': {
+                'host': host,
+                'writable': writable,
+                'preserve_snapshots': preserve_snapshots,
+                'nondisruptive': nondisruptive,
+                'new_share_network_id': new_share_network_id,
+            }
+        }
+
+        body = json.dumps(body)
+        resp, body = self.post('share-servers/%s/action' % share_server_id,
+                               body, headers=EXPERIMENTAL, extra_headers=True,
+                               version=version)
+        self.expected_success(200, resp.status)
+
+        return json.loads(body)
+
+    def share_server_migration_start(self, share_server_id, host,
+                                     writable=False, new_share_network_id=None,
+                                     preserve_snapshots=False,
+                                     nondisruptive=False,
+                                     version=LATEST_MICROVERSION):
+        body = {
+            'migration_start': {
+                'host': host,
+                'writable': writable,
+                'preserve_snapshots': preserve_snapshots,
+                'nondisruptive': nondisruptive,
+                'new_share_network_id': new_share_network_id,
+            }
+        }
+
+        body = json.dumps(body)
+        resp, body = self.post('share-servers/%s/action' % share_server_id,
+                               body, headers=EXPERIMENTAL, extra_headers=True,
+                               version=version)
+        self.expected_success(202, resp.status)
+
+        return body
+
+    def share_server_migration_complete(self, share_server_id,
+                                        version=LATEST_MICROVERSION):
+        body = {
+            'migration_complete': None
+        }
+
+        body = json.dumps(body)
+        resp, body = self.post('share-servers/%s/action' % share_server_id,
+                               body, headers=EXPERIMENTAL, extra_headers=True,
+                               version=version)
+        self.expected_success(200, resp.status)
+
+        return body
+
+    def share_server_migration_cancel(self, share_server_id,
+                                      version=LATEST_MICROVERSION):
+        body = {
+            'migration_cancel': None
+        }
+
+        body = json.dumps(body)
+        resp, body = self.post('share-servers/%s/action' % share_server_id,
+                               body, headers=EXPERIMENTAL, extra_headers=True,
+                               version=version)
+        self.expected_success(202, resp.status)
+
+        return body
+
+    def share_server_migration_get_progress(self, share_server_id,
+                                            version=LATEST_MICROVERSION):
+        body = {
+            'migration_get_progress': None
+        }
+
+        body = json.dumps(body)
+        resp, body = self.post('share-servers/%s/action' % share_server_id,
+                               body, headers=EXPERIMENTAL, extra_headers=True,
+                               version=version)
+        self.expected_sucess(200, resp.status)
+
+        return json.loads(body)
